pub struct Pill {
content: TemplateChild<Box>,
display_name: TemplateChild<Label>,
avatar: TemplateChild<Avatar>,
source: BoundObject<PillSource>,
activatable: Cell<bool>,
watched_safety_setting: PhantomData<AvatarImageSafetySetting>,
watched_room: PhantomData<Option<Room>>,
gesture_click: RefCell<Option<GestureClick>>,
}Fields
content: TemplateChild<Box>display_name: TemplateChild<Label>avatar: TemplateChild<Avatar>source: BoundObject<PillSource>The source of the data displayed by this widget.
activatable: Cell<bool>Whether the pill can be activated.
watched_safety_setting: PhantomData<AvatarImageSafetySetting>The safety setting to watch to decide whether the image of the avatar should be displayed.
watched_room: PhantomData<Option<Room>>The room to watch to apply the current safety settings.
This is required if watched_safety_setting is not None.
gesture_click: RefCell<Option<GestureClick>>Implementations
Sourceimpl Pill
impl Pill
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl Pill
impl Pill
Sourcefn set_source(&self, source: Option<PillSource>)
fn set_source(&self, source: Option<PillSource>)
Set the source of the data displayed by this widget.
Sourcefn set_activatable(&self, activatable: bool)
fn set_activatable(&self, activatable: bool)
Set whether this widget can be activated.
fn update_activatable_state(&self)
Sourcefn watched_safety_setting(&self) -> AvatarImageSafetySetting
fn watched_safety_setting(&self) -> AvatarImageSafetySetting
The safety setting to watch to decide whether the image of the avatar should be displayed.
Sourcefn set_watched_safety_setting(&self, setting: AvatarImageSafetySetting)
fn set_watched_safety_setting(&self, setting: AvatarImageSafetySetting)
Set the safety setting to watch to decide whether the image of the avatar should be displayed.
Sourcefn watched_room(&self) -> Option<Room>
fn watched_room(&self) -> Option<Room>
The room to watch to apply the current safety settings.
Sourcefn set_watched_room(&self, room: Option<Room>)
fn set_watched_room(&self, room: Option<Room>)
Set the room to watch to apply the current safety settings.
Sourcefn set_display_name(&self, label: &str)
fn set_display_name(&self, label: &str)
Set the display name of this pill.